package Lemonldap::NG::Handler;

# Use the appropriate handler
# For Apache, use Lemonldap::NG::Handler::ApacheMP2

our $VERSION = '2.21.2';

1;

__END__

=pod

=encoding utf8

=head1 NAME

Lemonldap::NG::Handler - The Apache protection module part of Lemonldap::NG Web-SSO system.

=head1 DESCRIPTION

This is an alias for L<Lemonldap::NG::Handler::ApacheMP2>

=head1 SEE ALSO

L<Lemonldap::NG::Handler::ApacheMP2>,
L<http://lemonldap-ng.org/>

=head1 AUTHORS

=over

=item LemonLDAP::NG team L<http://lemonldap-ng.org/team>

=back

=head1 BUG REPORT

Use OW2 system to report bug or ask for features:
L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>

=head1 DOWNLOAD

Lemonldap::NG is available at
L<https://lemonldap-ng.org/download>

=head1 COPYRIGHT AND LICENSE

See COPYING file for details.

This library is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.

=cut
